@@ -19,6 +19,8 @@ from sklearn import linear_model
 from sklearn.model_selection import cross_val_score, cross_val_predict
 import joblib
 from sklearn.linear_model import ElasticNet
+from sklearn.ensemble import RandomForestRegressor
+import xgboost as xgb
 
 #################################### Funciones ##############################################
 
@@ -562,11 +564,7 @@ def RegresionEleccion(df2,df3,cve,k):
         if maxi==c:
             c3=c3+1 
     p=max(c1,c2,c3)
-    if p==c1:
-        print("El método de regresión lineal escogido será sin indexación. Se procederá a guardarlo")
-        joblib.dump(regr1,"Rlineal1_"+str(cve)+".joblib")
-        return ytodos_test,y_pred13,regr1
-    elif p==c2:
+    if p==c2:
         print("El método de regresión lineal escogido será con indexación 10. Se procederá a guardarlo")
         joblib.dump(regr2,"Rlineal2_"+str(cve)+".joblib")
         return yrl10_test,y_pred16,regr2
@@ -574,6 +572,10 @@ def RegresionEleccion(df2,df3,cve,k):
         print("El método de regresión lineal escogido será con indexación 5. Se procederá a guardarlo")
         joblib.dump(regr3,"Rlineal3_"+str(cve)+".joblib")
         return yrl5_test,y_pred19,regr3
+    elif p==c1:
+        print("El método de regresión lineal escogido será sin indexación. Se procederá a guardarlo")
+        joblib.dump(regr1,"Rlineal1_"+str(cve)+".joblib")
+        return ytodos_test,y_pred13,regr1
 
 def GraEstModels(a,b,c,d,e,f,g,h):
     xvec=list(a)
@@ -783,17 +785,17 @@ def RForestEleccion(df2,df3,cve,k):
             c3=c3+1 
     p=max(c1,c2,c3)
     if p==c2:
-        print("El método de Random Forest escogido será sin indexación. Se procederá a guardarlo")
-        joblib.dump(rforest1,"RForest1_"+str(cve)+".joblib")
-        return ytodos_test,y_pred43,rforest1
-    elif p==c3:
         print("El método de Random Forest escogido será con indexación 10. Se procederá a guardarlo")
-        joblib.dump(rforest2,"RForest2_"+str(cve)+".joblib")
+        joblib.dump(rforest1,"RForest1_"+str(cve)+".joblib")
         return yrl10_test,y_pred46,rforest2
-    elif p==c1:
+    elif p==c3:
         print("El método de Random Forest escogido será con indexación 5. Se procederá a guardarlo")
-        joblib.dump(rforest3,"RForest3_"+str(cve)+".joblib")
+        joblib.dump(rforest2,"RForest2_"+str(cve)+".joblib")
         return yrl5_test,y_pred49,rforest3
+    elif p==c1:
+        print("El método de Random Forest escogido será sin indexación. Se procederá a guardarlo")
+        joblib.dump(rforest3,"RForest3_"+str(cve)+".joblib")
+        return ytodos_test,y_pred43,rforest1
 
 # XGB para un par de datos
 
@@ -844,18 +846,18 @@ def XGB_Eleccion(df2,df3,cve,k):
             c3=c3+1 
     p=max(c1,c2,c3)
     if p==c2:
-        print("El método de Xtreme Gradient Boosting escogido será sin indexación. Se procederá a guardarlo")
-        joblib.dump(xgb1,"XGB1_"+str(cve)+".joblib")
-        return ytodos_test,y_pred43,xgb1
-    elif p==c3:
         print("El método de Random Forest escogido será con indexación 10. Se procederá a guardarlo")
         joblib.dump(xgb2,"XGB2_"+str(cve)+".joblib")
-        return yrl10_test,y_pred46,xgb2
-    elif p==c1:
+        return yrl10_test,y_pred66,xgb2
+    elif p==c3:
         print("El método de Random Forest escogido será con indexación 5. Se procederá a guardarlo")
         joblib.dump(xgb3,"XGB3_"+str(cve)+".joblib")
-        return yrl5_test,y_pred49,xgb3
-
+        return yrl5_test,y_pred69,xgb3
+    elif p==c1:
+        print("El método de Xtreme Gradient Boosting escogido será sin indexación. Se procederá a guardarlo")
+        joblib.dump(xgb1,"XGB1_"+str(cve)+".joblib")
+        return ytodos_test,y_pred63,xgb1
+    
 # Error para los 4 modelos
 def porcentajeerror2(a,b,c,d,e,f,g,h):
     r1=100*(b-a)/a;
